==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ASigFieldRef.h <==
// public final class soot.jimple.parser.node.ASigFieldRef

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7de8d9bf52c1bab5 soot_jimple_parser_node_ASigFieldRef
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b0fed5aee3f1085f soot_jimple_parser_node_PFieldRef

// header file dependencies
// @dep_header soot_jimple_parser_node_PFieldRef

#include "soot/jimple/parser/node/PFieldRef.h"

#ifndef _JC_soot_jimple_parser_node_ASigFieldRef_H_
#define _JC_soot_jimple_parser_node_ASigFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PFieldSignature$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$sub_refs	_jc_soot_jimple_parser_node_ASigFieldRef$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$sub_nonrefs	_jc_soot_jimple_parser_node_ASigFieldRef$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$refs	_jc_soot_jimple_parser_node_ASigFieldRef$refs;
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$nonrefs	_jc_soot_jimple_parser_node_ASigFieldRef$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$object	_jc_soot_jimple_parser_node_ASigFieldRef$object;

typedef const struct _jc_soot_jimple_parser_node_ASigFieldRef$vmethods	_jc_soot_jimple_parser_node_ASigFieldRef$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASigFieldRef$vtable	_jc_soot_jimple_parser_node_ASigFieldRef$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASigFieldRef$vtype	_jc_soot_jimple_parser_node_ASigFieldRef$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *);
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$_init$a2f7573213f2609e(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_PFieldSignature$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASigFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *);
extern struct _jc_soot_jimple_parser_node_PFieldSignature$object *_jc_soot_jimple_parser_node_ASigFieldRef$method$getFieldSignature$029966aba63e7334(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *);
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$setFieldSignature$9f2d9331352d6433(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_PFieldSignature$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASigFieldRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$getFieldSignature$029966aba63e7334;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$setFieldSignature$9f2d9331352d6433;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASigFieldRef$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *);
	struct _jc_soot_jimple_parser_node_PFieldSignature$object	*(*getFieldSignature$029966aba63e7334)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setFieldSignature$9f2d9331352d6433)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_PFieldSignature$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ASigFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PFieldRef$vmethods	soot_jimple_parser_node_PFieldRef;
	_jc_soot_jimple_parser_node_ASigFieldRef$vmethods	soot_jimple_parser_node_ASigFieldRef;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASigFieldRef$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASigFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASigFieldRef$sub_refs {
	struct _jc_soot_jimple_parser_node_PFieldSignature$object	*__5ffieldSignature__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASigFieldRef$refs {
    _jc_soot_jimple_parser_node_ASigFieldRef$sub_refs	soot_jimple_parser_node_ASigFieldRef;
    _jc_soot_jimple_parser_node_PFieldRef$sub_refs	soot_jimple_parser_node_PFieldRef;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASigFieldRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASigFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PFieldRef$sub_nonrefs	soot_jimple_parser_node_PFieldRef;
    _jc_soot_jimple_parser_node_ASigFieldRef$sub_nonrefs	soot_jimple_parser_node_ASigFieldRef;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASigFieldRef$object {
	_jc_soot_jimple_parser_node_ASigFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASigFieldRef$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASigFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASigFieldRef$vtype _jc_soot_jimple_parser_node_ASigFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASigFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASigFieldRef$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASigFieldRef_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ASigFieldRef.h <==
// public final class soot.jimple.parser.node.ASigFieldRef

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7de8d9bf52c1bab5 soot_jimple_parser_node_ASigFieldRef
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b0fed5aee3f1085f soot_jimple_parser_node_PFieldRef

// header file dependencies
// @dep_header soot_jimple_parser_node_PFieldRef

#include "soot/jimple/parser/node/PFieldRef.h"

#ifndef _JC_soot_jimple_parser_node_ASigFieldRef_H_
#define _JC_soot_jimple_parser_node_ASigFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PFieldSignature$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$sub_refs	_jc_soot_jimple_parser_node_ASigFieldRef$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$sub_nonrefs	_jc_soot_jimple_parser_node_ASigFieldRef$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$refs	_jc_soot_jimple_parser_node_ASigFieldRef$refs;
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$nonrefs	_jc_soot_jimple_parser_node_ASigFieldRef$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASigFieldRef$object	_jc_soot_jimple_parser_node_ASigFieldRef$object;

typedef const struct _jc_soot_jimple_parser_node_ASigFieldRef$vmethods	_jc_soot_jimple_parser_node_ASigFieldRef$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASigFieldRef$vtable	_jc_soot_jimple_parser_node_ASigFieldRef$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASigFieldRef$vtype	_jc_soot_jimple_parser_node_ASigFieldRef$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$_init$a2f7573213f2609e(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_PFieldSignature$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASigFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PFieldSignature$object *_jc_soot_jimple_parser_node_ASigFieldRef$method$getFieldSignature$029966aba63e7334(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASigFieldRef$method$setFieldSignature$9f2d9331352d6433(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_PFieldSignature$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASigFieldRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$getFieldSignature$029966aba63e7334;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$setFieldSignature$9f2d9331352d6433;
extern _jc_method _jc_soot_jimple_parser_node_ASigFieldRef$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASigFieldRef$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PFieldSignature$object	*(*getFieldSignature$029966aba63e7334)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setFieldSignature$9f2d9331352d6433)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *, struct _jc_soot_jimple_parser_node_PFieldSignature$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASigFieldRef$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ASigFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PFieldRef$vmethods	soot_jimple_parser_node_PFieldRef;
	_jc_soot_jimple_parser_node_ASigFieldRef$vmethods	soot_jimple_parser_node_ASigFieldRef;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASigFieldRef$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASigFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASigFieldRef$sub_refs {
	struct _jc_soot_jimple_parser_node_PFieldSignature$object	*__5ffieldSignature__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASigFieldRef$refs {
    _jc_soot_jimple_parser_node_ASigFieldRef$sub_refs	soot_jimple_parser_node_ASigFieldRef;
    _jc_soot_jimple_parser_node_PFieldRef$sub_refs	soot_jimple_parser_node_PFieldRef;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASigFieldRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASigFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PFieldRef$sub_nonrefs	soot_jimple_parser_node_PFieldRef;
    _jc_soot_jimple_parser_node_ASigFieldRef$sub_nonrefs	soot_jimple_parser_node_ASigFieldRef;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASigFieldRef$object {
	_jc_soot_jimple_parser_node_ASigFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASigFieldRef$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASigFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASigFieldRef$vtype _jc_soot_jimple_parser_node_ASigFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASigFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASigFieldRef$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASigFieldRef_H_ */
